BYPASS: int = 0
"""No timeout."""

VERY_SHORT: int = 1
"""Very short timeout: 1 second."""

SHORT: int = 3
"""Short timeout: 3 seconds."""

DEFAULT: int = 5
"""Default timeout: 5 seconds."""

LONG: int = 10
"""Long timeout: 10 seconds."""
